==> zio-aws-wafregional_3-5.17.121.3-sources.jar: zio/aws/wafregional/model/ListGeoMatchSetsResponse.scala <==
package zio.aws.wafregional.model
import zio.aws.wafregional.model.primitives.NextMarker
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ListGeoMatchSetsResponse(
    nextMarker: Option[NextMarker] = None,
    geoMatchSets: Option[
      Iterable[zio.aws.wafregional.model.GeoMatchSetSummary]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.ListGeoMatchSetsResponse = {
    import ListGeoMatchSetsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.ListGeoMatchSetsResponse
      .builder()
      .optionallyWith(
        nextMarker.map(value => NextMarker.unwrap(value): java.lang.String)
      )(_.nextMarker)
      .optionallyWith(
        geoMatchSets.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.geoMatchSets)
      .build()
  }
  def asReadOnly: zio.aws.wafregional.model.ListGeoMatchSetsResponse.ReadOnly =
    zio.aws.wafregional.model.ListGeoMatchSetsResponse.wrap(buildAwsValue())
}
object ListGeoMatchSetsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.ListGeoMatchSetsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.wafregional.model.ListGeoMatchSetsResponse =
      zio.aws.wafregional.model.ListGeoMatchSetsResponse(
        nextMarker.map(value => value),
        geoMatchSets.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def nextMarker: Option[NextMarker]
    def geoMatchSets
        : Option[List[zio.aws.wafregional.model.GeoMatchSetSummary.ReadOnly]]
    def getNextMarker: ZIO[Any, AwsError, NextMarker] =
      AwsError.unwrapOptionField("nextMarker", nextMarker)
    def getGeoMatchSets: ZIO[Any, AwsError, List[
      zio.aws.wafregional.model.GeoMatchSetSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("geoMatchSets", geoMatchSets)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.ListGeoMatchSetsResponse
  ) extends zio.aws.wafregional.model.ListGeoMatchSetsResponse.ReadOnly {
    override val nextMarker: Option[NextMarker] = scala
      .Option(impl.nextMarker())
      .map(value => zio.aws.wafregional.model.primitives.NextMarker(value))
    override val geoMatchSets
        : Option[List[zio.aws.wafregional.model.GeoMatchSetSummary.ReadOnly]] =
      scala
        .Option(impl.geoMatchSets())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.wafregional.model.GeoMatchSetSummary.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.ListGeoMatchSetsResponse
  ): zio.aws.wafregional.model.ListGeoMatchSetsResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-wafregional_3-6.20.74.1-sources.jar: zio/aws/wafregional/model/ListGeoMatchSetsResponse.scala <==
package zio.aws.wafregional.model
import zio.aws.wafregional.model.primitives.NextMarker
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ListGeoMatchSetsResponse(
    nextMarker: Optional[NextMarker] = Optional.Absent,
    geoMatchSets: Optional[
      Iterable[zio.aws.wafregional.model.GeoMatchSetSummary]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.ListGeoMatchSetsResponse = {
    import ListGeoMatchSetsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.ListGeoMatchSetsResponse
      .builder()
      .optionallyWith(
        nextMarker.map(value => NextMarker.unwrap(value): java.lang.String)
      )(_.nextMarker)
      .optionallyWith(
        geoMatchSets.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.geoMatchSets)
      .build()
  }
  def asReadOnly: zio.aws.wafregional.model.ListGeoMatchSetsResponse.ReadOnly =
    zio.aws.wafregional.model.ListGeoMatchSetsResponse.wrap(buildAwsValue())
}
object ListGeoMatchSetsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.ListGeoMatchSetsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.wafregional.model.ListGeoMatchSetsResponse =
      zio.aws.wafregional.model.ListGeoMatchSetsResponse(
        nextMarker.map(value => value),
        geoMatchSets.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def nextMarker: Optional[NextMarker]
    def geoMatchSets
        : Optional[List[zio.aws.wafregional.model.GeoMatchSetSummary.ReadOnly]]
    def getNextMarker: ZIO[Any, AwsError, NextMarker] =
      AwsError.unwrapOptionField("nextMarker", nextMarker)
    def getGeoMatchSets: ZIO[Any, AwsError, List[
      zio.aws.wafregional.model.GeoMatchSetSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("geoMatchSets", geoMatchSets)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.ListGeoMatchSetsResponse
  ) extends zio.aws.wafregional.model.ListGeoMatchSetsResponse.ReadOnly {
    override val nextMarker: Optional[NextMarker] = zio.aws.core.internal
      .optionalFromNullable(impl.nextMarker())
      .map(value => zio.aws.wafregional.model.primitives.NextMarker(value))
    override val geoMatchSets: Optional[
      List[zio.aws.wafregional.model.GeoMatchSetSummary.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.geoMatchSets())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.wafregional.model.GeoMatchSetSummary.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.ListGeoMatchSetsResponse
  ): zio.aws.wafregional.model.ListGeoMatchSetsResponse.ReadOnly = new Wrapper(
    impl
  )
}
